<?php

namespace App\Core;

class Env {
    private static $variables = [];

    // Cargar las variables del archivo .env
    public static function load($filePath) {
        if (!file_exists($filePath)) {
            throw new \Exception("Archivo .env no encontrado en: $filePath");
        }

        // Leer el archivo línea por línea
        $lines = file($filePath, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);

        foreach ($lines as $line) {
            // Ignorar comentarios
            if (strpos(trim($line), '#') === 0) {
                continue;
            }

            // Dividir clave y valor
            list($key, $value) = explode('=', $line, 2);

            $key = trim($key);
            $value = trim($value);

            // Eliminar comillas alrededor del valor, si existen
            $value = trim($value, '"\'');

            // Guardar en el arreglo y como variable de entorno
            self::$variables[$key] = $value;
            putenv("$key=$value");
            $_ENV[$key] = $value;
        }
    }

    // Obtener una variable de entorno
    public static function get($key, $default = null) {
        return self::$variables[$key] ?? getenv($key) ?? $_ENV[$key] ?? $default;
    }
}

