<?php

namespace App\Core;

// Este bloque define la clase principal del enrutador
class Router {
    // Esta propiedad almacena todas las rutas de la aplicación
    private $routes = [];

    // Este bloque inicializa las rutas en el constructor
    public function __construct() {
        // Definir las rutas estáticas y dinámicas
        $this->routes = [
            // Ruta raíz
            '/' => ['controller' => 'App\Controllers\InicioController', 'method' => 'showInicio'],
            //Inicio
            '/Inicio' => ['controller' => 'App\Controllers\InicioController', 'method' => 'showInicio'],
            // Ruta para mostrar el índice de una categoría (ej. /redes)
            '/{categoria}' => ['controller' => 'App\Controllers\PaginaController', 'method' => 'mostrarIndice'],
            // Ruta para una noticia por título (ej. /redes/Nuevos-cables-de-red)
            '/{categoria}/{titulo}' => ['controller' => 'App\Controllers\PaginaController', 'method' => 'mostrarNoticiaPorTitulo'],
            // Ruta para una noticia por ID (ej. /redes/345)
            '/{categoria}/{id}' => ['controller' => 'App\Controllers\PaginaController', 'method' => 'mostrarNoticiaPorId'],
            // Ruta para una página estática de Contactos
            '/contactos' => ['controller' => 'App\Controllers\PaginaEstaticasController', 'method' => 'mostrarContactos'],
        ];
    }

    public function run() {
        // Obtener la URI de la solicitud
        $requestUri = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
        $requestUri = rtrim($requestUri, '/');
        
        // Verificar si la ruta es vacía y establecerla como raíz
        if ($requestUri === '') {
            $requestUri = '/';
        }
        
        
        // Primero verificar rutas estáticas
        if (isset($this->routes[$requestUri])) {
            $route = $this->routes[$requestUri];
            $controllerName = $route['controller'];
            $methodName = $route['method'];

            if (class_exists($controllerName) && method_exists($controllerName, $methodName)) {
                $controller = new $controllerName();
                $controller->$methodName();
                return; // Terminar la ejecución una vez encontrada la ruta estática
            } else {
                $this->handleError(404, "Método o controlador no encontrado.");
            }
        }

        // Luego verificar rutas dinámicas
        foreach ($this->routes as $route => $data) {
            // Generar el patrón de ruta para variables dinámicas
            $pattern = "@^" . preg_replace('/\{[a-zA-Z0-9_]+\}/', '([a-zA-Z0-9_]+)', $route) . "$@D";
            if (preg_match($pattern, $requestUri, $matches)) {
                array_shift($matches); // Remover la URL completa del array de coincidencias
                $controllerName = $data['controller'];
                $methodName = $data['method'];

                if (class_exists($controllerName) && method_exists($controllerName, $methodName)) {
                    $controller = new $controllerName();
                    $controller->$methodName(...$matches);
                    return; // Terminar la ejecución una vez encontrada la ruta dinámica
                } else {
                    $this->handleError(404, "Método o controlador no encontrado.");
                }
            }
        }

        // Si no se encuentra ninguna ruta, manejar el error
        $this->handleError(404, "Ruta no encontrada.");
    }

    // Este bloque maneja errores y responde con el mensaje apropiado
    private function handleError($statusCode, $message) {
        http_response_code($statusCode); // Configurar el código de estado HTTP
        echo "<h1>Error $statusCode</h1>";
        echo "<p>$message</p>";
    }
}
 
