<?php

// Cargar el archivo de variables de entorno
require_once __DIR__ . '/../App/Core/Env.php';

// Cargar las variables del archivo .env
\App\Core\Env::load(__DIR__ . '/../App/Core/.env');

// Definir constantes globales usando las variables cargadas
define('DB_HOST', \App\Core\Env::get('DB_HOST'));
define('DB_NAME', \App\Core\Env::get('DB_NAME'));
define('DB_USER', \App\Core\Env::get('DB_USER'));
define('DB_PASS', \App\Core\Env::get('DB_PASS'));
define('APP_ENV', \App\Core\Env::get('APP_ENV', 'production'));
define('APP_DEBUG', filter_var(\App\Core\Env::get('APP_DEBUG', false), FILTER_VALIDATE_BOOLEAN));

// Manejo de errores según el entorno
if (APP_DEBUG) {
    ini_set('display_errors', 1);
    ini_set('display_startup_errors', 1);
    error_reporting(E_ALL);
} else {
    ini_set('display_errors', 0);
    ini_set('display_startup_errors', 0);
    ini_set('log_errors', 1);
    ini_set('error_log', __DIR__ . '/../storage/logs/error.log');
    error_reporting(E_ALL);
}


// Iniciar sesión si es necesario
session_start();

// Verificar que el autoload de Composer se cargó
require_once __DIR__ . '/../vendor/autoload.php';

// Cargar y ejecutar el middleware principal
require_once __DIR__ . '/../App/Middlewares/middleware.php';


if (!class_exists('App\Core\Router')) {
    die('Error: La clase Router no está disponible.');
}

if (!class_exists('App\Middlewares\Middleware')) {
    die('Error: La clase Middleware no está disponible.');
}


$middleware = new \App\Middlewares\Middleware();
$middleware->handleBadAgents(); // Ejecutar el middleware de agentes maliciosos


// Instanciar el router y manejar la solicitud
$router = new App\Core\Router();
$router->run();
